pub struct EcdsaSignature {
pub(crate) expanded_sig: Vec<u8>,
}Expand description
A signature for ECDSA cryptographic operations.
This struct encapsulates the components of an ECDSA signature, which include the ‘r’ and ‘s’ values as byte arrays, a ‘v’ recovery id, and the signature in DER encoding. The ‘r’ and ‘s’ components are the main parts of the signature, ‘v’ is used to recover the public key from the signature, and the DER encoding is used for compatibility with systems that require the signature in ASN.1/DER format.
Fields
expanded_sig: Vec<u8>Implementations
Sourceimpl EcdsaSignature
impl EcdsaSignature
Sourcepub(crate) const FIELD_SIZE: usize = 32usize
pub(crate) const FIELD_SIZE: usize = 32usize
The size of a field element in bytes (32 bytes for secp256k1).
Sourcepub(crate) const MIN_SIZE: usize = 73usize
pub(crate) const MIN_SIZE: usize = 73usize
Minimum size: 2 field elements + minimum 8 DER bytes + 1 v byte.